@@ -50,7 +50,7 @@ const WaveForm = new Lang.Class({
 
     _init: function(grid, file) {
         this._grid = grid;
-        
+
         let placeHolder = -100;
         for (let i = 0; i < 40; i++)
             peaks.push(placeHolder);
@@ -61,34 +61,29 @@ const WaveForm = new Lang.Class({
             this._uri = this.file.uri;
         } else {
           this.waveType = WaveType.RECORD;
-        }  
-        
+        }
+
         let gridWidth = 0;
         let drawingWidth = 0;
         let drawingHeight = 0;
-        this.drawing = Gtk.DrawingArea.new({ height_request: 45,
-                                             width_request: 300,
-                                             valign: Gtk.Align.FILL });
+        this.drawing = Gtk.DrawingArea.new();
         if (this.waveType == WaveType.RECORD) {
-            gridWidth = MainWindow.groupGrid.get_allocated_width();
-            drawingWidth = gridWidth * 0.75;
-            this.drawing.set_size_request(drawingWidth, 36);
+            this.drawing.set_property("valign", Gtk.Align.FILL);
             this.drawing.set_property("hexpand",true);
             this._grid.attach(this.drawing, 2, 0, 3, 2);
         } else {
-            gridWidth = this._grid.get_allocated_width();
-            gridWidth = gridWidth * 0.70;
-            this.drawing.set_size_request(gridWidth, 45);
+            this.drawing.set_property("valign", Gtk.Align.FILL);
             this.drawing.set_property("hexpand",true);
+            this.drawing.set_property("vexpand",true);
             this._grid.add(this.drawing);
         }
 
         this.drawing.connect("draw", Lang.bind(this, this.fillSurface));
         this.drawing.show_all();
         this._grid.show_all();
-        
-        if (this.waveType == WaveType.PLAY) { 
-            this._launchPipeline();            
+
+        if (this.waveType == WaveType.PLAY) {
+            this._launchPipeline();
             this.startGeneration();
         }
     },
@@ -107,7 +102,7 @@ const WaveForm = new Lang.Class({
 
         bus.connect("message", Lang.bind(this,
             function(bus, message) {
-            
+
                 if (message != null) {
                     this._messageCb(message);
                 }
@@ -116,41 +111,41 @@ const WaveForm = new Lang.Class({
 
     _messageCb: function(message) {
         let msg = message.type;
-        
+
         switch(msg) {
         case Gst.MessageType.ELEMENT:
             let s = message.get_structure();
-            
+
             if (s) {
-                
+
                 if (s.has_name("level")) {
                     let peaknumber = 0;
                     let st = s.get_value("timestamp");
                     let dur = s.get_value("duration");
                     let runTime = s.get_value("running-time");
                     let peakVal = s.get_value("peak");
-                
+
                     if (peakVal) {
                         let val = peakVal.get_nth(0);
-                            
+
                         if (val > 0)
                             val = 0;
-                                    
+
                         let value = Math.pow(10, val/20);
                         peaks.push(value);
-                    }                            
+                    }
                 }
             }
 
             if (peaks.length == this.playTime) {
-                this.pipeline.set_state(Gst.State.PAUSED);                    
+                this.pipeline.set_state(Gst.State.PAUSED);
             }
-                
+
             if (peaks.length == pauseVal) {
                 this.pipeline.set_state(Gst.State.PAUSED);
-            }                                      
+            }
             break;
-                       
+
         case Gst.MessageType.EOS:
             this.stopGeneration();
             break;
@@ -164,105 +159,103 @@ const WaveForm = new Lang.Class({
     stopGeneration: function() {
         this.pipeline.set_state(Gst.State.NULL);
     },
-                
+
     fillSurface: function(drawing, cr) {
         let start = 0;
-        
-        if (this.waveType == WaveType.PLAY) { 
-                   
-            if (peaks.length != this.playTime) { 
+
+        if (this.waveType == WaveType.PLAY) {
+
+            if (peaks.length != this.playTime) {
                 this.pipeline.set_state(Gst.State.PLAYING);
             }
             start = Math.floor(this.playTime);
         } else {
-        
+
             if (this.recordTime >= 0)
             start = this.recordTime;
         }
-        
+
         let i = 0;
         let xAxis = 0;
         let end = start + 40;
         let width = this.drawing.get_allocated_width();
         let waveheight = this.drawing.get_allocated_height();
         let length = this.nSamples;
-        let pixelsPerSample = width/waveSamples;   
+        let pixelsPerSample = width/waveSamples;
         let gradient = new Cairo.LinearGradient(0, 0, width , waveheight);
-        if (this.waveType == WaveType.PLAY) { 
-              gradient.addColorStopRGBA(0.75, 0.94, 1.0, 0.94, 0.75);       
+        if (this.waveType == WaveType.PLAY) {
+              gradient.addColorStopRGBA(0.75, 0.94, 1.0, 0.94, 0.75);
               gradient.addColorStopRGBA(0.0, 0.94, 1.0, 0.94, 0.22);
               cr.setLineWidth(1);
               cr.setSourceRGBA(0.0, 255, 255, 255);
         } else {
-            gradient.addColorStopRGBA(0.75, 0.0, 0.72, 0.64, 0.35);       
+            gradient.addColorStopRGBA(0.75, 0.0, 0.72, 0.64, 0.35);
             gradient.addColorStopRGBA(0.0, 0.2, 0.54, 0.47, 0.22);
             cr.setLineWidth(1);
             cr.setSourceRGBA(0.0, 185, 161, 255);
         }
-                  
+
         for(i = start; i <= end; i++) {
-        
+
             // Keep moving until we get to a non-null array member
-            if (peaks[i] < 0) {            
+            if (peaks[i] < 0) {
                 cr.moveTo((xAxis * pixelsPerSample), (waveheight - (peaks[i] * waveheight)))
             }
-      
-            // Start drawing when we reach the first non-null array member  
+
+            // Start drawing when we reach the first non-null array member
             if (peaks[i] != null && peaks[i] >= 0) {
                 let idx = i - 1;
-                
-                if (start >= 40 && xAxis == 0) { 
+
+                if (start >= 40 && xAxis == 0) {
                      cr.moveTo((xAxis * pixelsPerSample), waveheight);
                 }
-                
+
                 cr.lineTo((xAxis * pixelsPerSample), (waveheight - (peaks[i] * waveheight)));
             }
-                                
+
             xAxis += 1;
         }
         cr.lineTo(xAxis * pixelsPerSample, waveheight);
         cr.closePath();
-        cr.strokePreserve();       
+        cr.strokePreserve();
         cr.setSource(gradient);
 	    cr.fillPreserve();
-	    cr.$dispose(); 
+	    cr.$dispose();
     },
-    
+
     _drawEvent: function(playTime, recPeaks) {
         let lastTime;
-        
+
         if (this.waveType == WaveType.PLAY) {
             lastTime = this.playTime;
             this.playTime = playTime;
-                  
+
             if (peaks.length < this.playTime) {
                 this.pipeline.set_state(Gst.State.PLAYING);
-            } 
-                    
+            }
+
             if (lastTime != this.playTime) {
                 this.drawing.queue_draw();
             }
-            
+
         } else {
             peaks.push(recPeaks);
             lastTime = this.recordTime;
             this.recordTime = playTime;
-                  
+
             if (peaks.length < this.recordTime) {
                 log("error");
             }
-                      
+
             this.drawing.queue_draw();
         }
         return true;
     },
-    
+
     endDrawing: function() {
-        let width = 380;
-        
         if(this.pipeline)
             this.stopGeneration();
-            
+
         this.count = 0;
         peaks.length = 0;
         this.drawing.destroy();
